function com_norm = approximate_norm(A,B,delta,eta)
% Approximates the norm of (I otimes A(delta)) - (A(delta)-etaI otimes I).
% The accuracy of the algorithm for the distance to uncontrollability 
% based on real eigenvalue extraction depends on this norm.

[sar,sac] = size(A);

% compute the smallest condition number
% VR contains right eigenvectors
[VR,D] = eig(A);
d = diag(D);
% VL contains left eigenvectors
[VL,DC] = eig(A');
dc = diag(DC);

smallest = 1;
for j = 1:sar
    [mv,indx] = min(abs(dc(j)-d'));
    smallest = min(abs(VL(:,j)'*VR(:,indx)),smallest);
end

com_norm = 2*norm(A) + (2*norm(B*B'/delta-delta*eye(sar))+delta)^2/(2*eta*smallest);

return;