function [alpha,wbest] = cdi_alpha(A,wmid)
% Michael Overton and Emre Mengi (Last updated March 11 2005)
%
% called by cdi.m
%
% Computes f(w) = sigma_min(A-wiI) at each point w in wmid.
% Returns alpha = min{f(w)| w in wmid} and wbest satisfying 
% f(wbest) = alpha.
%
% Input:
%       A       : Input matrix(must be square)
%       wmid    : Set of midpoints
%
% Output:
%       alpha   : Minimum function value among the function
%                 values at midpoints.
%       wbest   : One of the midpoints at which the function
%                 value is minimum.



n = length(A);
if size(A) ~= [n,n]
    error('A must be square')
end

for j = 1:length(wmid)
    % compute f(w) at the jth midpoint in wmid
    s = svd(A-wmid(j)*i*eye(n));
    alphamin(j) = min(s);
end

% min of min singular values
[minval,minind] = min(alphamin);

% set the return variables
alpha = minval;
wbest = wmid(minind);

return;