function [alpha,thetabest] = ddi_alpha(A,thetamid)
% Emre Mengi and Michael Overton (Last updated on March 16 2005)
%
% called by ddi.m
%
% Computes g(theta) = sigma_min(A-e^{i*theta}*I) at each point 
% theta in thetamid. Returns alpha = min{g(theta)| theta in thetamid}
% and thetabest satisfying g(thetabest) = alpha.
%
% Input:
%       A           : Input matrix (must be square)
%       thetamid    : Set of midangles
%
% Output:
%       alpha       : Minimum function value among the function
%                     values at midpoints.
%       thetabest   : One of the midpoints at which the function
%                     is minimum.


% get the size of the input matrix and check whether it's square or not.
n = length(A);
if size(A) ~= [n,n]
    error('A must be square')
end

for j = 1:length(thetamid)
    % compute g(theta) at the jth midpoint in thetamid
    s = svd(A-exp(thetamid(j)*i)*eye(n));    
    alphamin(j) = min(s);
end

% min of min singular values
[minval,minind] = min(alphamin);

% set the return variables
alpha = minval;
thetabest = thetamid(minind);

return;