function [alpha,thetabest] = poly_ddi_alpha(P,gamma,thetamid)
% Emre Mengi and Michael Overton (Last updated on June 30 2006)
%
% called by poly_ddi.m
%
% Computes g(theta) = sigma_min(P(e^{itheta}))/||gamma|| at each point 
% theta in thetamid. Returns alpha = min{g(theta)| theta in thetamid}
% and thetabest satisfying g(thetabest) = alpha.
%
% Input:
%       P           : Input matrix polynomial (must be square)
%       gamma       : Vector of scaling parameters.
%       thetamid    : Set of midangles
%
% Output:
%       alpha       : Minimum function value among the function
%                     values at midpoints.
%       thetabest   : One of the midpoints at which the function
%                     is minimum.


% get the size of the input matrix and check whether it's square or not.
[nr,nc,kp] = size(P);
if nr ~= nc
    error('P must be square')
end
n = nr;
k = kp-1;

for j = 1:length(thetamid)
    % compute g(theta) at the jth midpoint in thetamid
    alphamin(j) = compute_sing(P,gamma,exp(thetamid(j)*i));
end

% min of min singular values
[minval,minind] = min(alphamin);

% set the return variables
alpha = minval;
thetabest = thetamid(minind);

return;